Package org.apache.flink.table.api
Enum InsertConflictStrategy.ConflictBehavior
- java.lang.Object
-
- java.lang.Enum<InsertConflictStrategy.ConflictBehavior>
-
- org.apache.flink.table.api.InsertConflictStrategy.ConflictBehavior
-
- All Implemented Interfaces:
Serializable,Comparable<InsertConflictStrategy.ConflictBehavior>
- Enclosing class:
- InsertConflictStrategy
@PublicEvolving public static enum InsertConflictStrategy.ConflictBehavior extends Enum<InsertConflictStrategy.ConflictBehavior>
Defines the basic conflict resolution behaviors.
-
-
Enum Constant Summary
Enum Constants Enum Constant Description DEDUPLICATEMaintain the full history of changes for each primary key to support rollback on retraction.ERRORThrow an exception when multiple distinct records arrive for the same primary key after watermark compaction.NOTHINGKeep the first record that arrives for a given primary key, discard subsequent conflicts.
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static InsertConflictStrategy.ConflictBehaviorvalueOf(String name)Returns the enum constant of this type with the specified name.static InsertConflictStrategy.ConflictBehavior[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
ERROR
public static final InsertConflictStrategy.ConflictBehavior ERROR
Throw an exception when multiple distinct records arrive for the same primary key after watermark compaction.
-
NOTHING
public static final InsertConflictStrategy.ConflictBehavior NOTHING
Keep the first record that arrives for a given primary key, discard subsequent conflicts.
-
DEDUPLICATE
public static final InsertConflictStrategy.ConflictBehavior DEDUPLICATE
Maintain the full history of changes for each primary key to support rollback on retraction. This is the current default behavior.
-
-
Method Detail
-
values
public static InsertConflictStrategy.ConflictBehavior[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (InsertConflictStrategy.ConflictBehavior c : InsertConflictStrategy.ConflictBehavior.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static InsertConflictStrategy.ConflictBehavior valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
-