Uses of Class
org.apache.flink.table.api.InsertConflictStrategy
-
Packages that use InsertConflictStrategy Package Description org.apache.flink.table.api org.apache.flink.table.api.internal org.apache.flink.table.operations -
-
Uses of InsertConflictStrategy in org.apache.flink.table.api
Methods in org.apache.flink.table.api that return InsertConflictStrategy Modifier and Type Method Description InsertConflictStrategyInsertConflictStrategy.Builder. build()Builds theInsertConflictStrategy.static InsertConflictStrategyInsertConflictStrategy. deduplicate()Creates a strategy that maintains the full history of changes for each primary key to support rollback on retraction.static InsertConflictStrategyInsertConflictStrategy. error()Creates a strategy that throws an exception when multiple distinct records arrive for the same primary key after watermark compaction.static InsertConflictStrategyInsertConflictStrategy. nothing()Creates a strategy that keeps the first record that arrives for a given primary key and discards subsequent conflicts.Methods in org.apache.flink.table.api with parameters of type InsertConflictStrategy Modifier and Type Method Description default TableResultTable. executeInsert(String tablePath, InsertConflictStrategy conflictStrategy)Shorthand fortableEnv.insertInto(tablePath, conflictStrategy).execute().default TableResultTable. executeInsert(String tablePath, InsertConflictStrategy conflictStrategy, boolean overwrite)Shorthand fortableEnv.insertInto(tablePath, conflictStrategy, overwrite).execute().default TableResultTable. executeInsert(TableDescriptor descriptor, InsertConflictStrategy conflictStrategy)Shorthand fortableEnv.insertInto(descriptor, conflictStrategy).execute().default TableResultTable. executeInsert(TableDescriptor descriptor, InsertConflictStrategy conflictStrategy, boolean overwrite)Shorthand fortableEnv.insertInto(descriptor, conflictStrategy, overwrite).execute().TablePipelineTable. insertInto(String tablePath, InsertConflictStrategy conflictStrategy)Declares that the pipeline defined by the givenTableobject should be written to a table (backed by aDynamicTableSink) that was registered under the specified path.TablePipelineTable. insertInto(String tablePath, InsertConflictStrategy conflictStrategy, boolean overwrite)Declares that the pipeline defined by the givenTableobject should be written to a table (backed by aDynamicTableSink) that was registered under the specified path.TablePipelineTable. insertInto(TableDescriptor descriptor, InsertConflictStrategy conflictStrategy)Declares that the pipeline defined by the givenTableobject should be written to a table (backed by aDynamicTableSink) expressed via the givenTableDescriptor.TablePipelineTable. insertInto(TableDescriptor descriptor, InsertConflictStrategy conflictStrategy, boolean overwrite)Declares that the pipeline defined by the givenTableobject should be written to a table (backed by aDynamicTableSink) expressed via the givenTableDescriptor. -
Uses of InsertConflictStrategy in org.apache.flink.table.api.internal
Methods in org.apache.flink.table.api.internal with parameters of type InsertConflictStrategy Modifier and Type Method Description TablePipelineTableImpl. insertInto(String tablePath, InsertConflictStrategy conflictStrategy)TablePipelineTableImpl. insertInto(String tablePath, InsertConflictStrategy conflictStrategy, boolean overwrite)TablePipelineTableImpl. insertInto(TableDescriptor descriptor, InsertConflictStrategy conflictStrategy)TablePipelineTableImpl. insertInto(TableDescriptor descriptor, InsertConflictStrategy conflictStrategy, boolean overwrite) -
Uses of InsertConflictStrategy in org.apache.flink.table.operations
Methods in org.apache.flink.table.operations that return types with arguments of type InsertConflictStrategy Modifier and Type Method Description Optional<InsertConflictStrategy>ExternalModifyOperation. getConflictStrategy()Returns the conflict resolution strategy if specified via ON CONFLICT clause.Optional<InsertConflictStrategy>SinkModifyOperation. getConflictStrategy()Returns the conflict resolution strategy if specified via ON CONFLICT clause.Constructors in org.apache.flink.table.operations with parameters of type InsertConflictStrategy Constructor Description ExternalModifyOperation(ContextResolvedTable contextResolvedTable, QueryOperation child, org.apache.flink.table.connector.ChangelogMode changelogMode, org.apache.flink.table.types.DataType physicalDataType, InsertConflictStrategy conflictStrategy)SinkModifyOperation(ContextResolvedTable contextResolvedTable, QueryOperation child, Map<String,String> staticPartitions, int[][] targetColumns, boolean overwrite, Map<String,String> dynamicOptions, ModifyType modifyType, InsertConflictStrategy conflictStrategy)
-