Uses of Interface
org.apache.flink.table.api.Model
-
Packages that use Model Package Description org.apache.flink.table.api org.apache.flink.table.api.internal org.apache.flink.table.expressions -
-
Uses of Model in org.apache.flink.table.api
Methods in org.apache.flink.table.api that return Model Modifier and Type Method Description ModelTableEnvironment. fromModel(String modelPath)Returns aModelobject that is backed by the specified model path.ModelTableEnvironment. fromModel(ModelDescriptor descriptor)Returns aModelobject that is backed by the specifiedModelDescriptor. -
Uses of Model in org.apache.flink.table.api.internal
Classes in org.apache.flink.table.api.internal that implement Model Modifier and Type Class Description classModelImplImplementation ofModelthat works with the Table API.Methods in org.apache.flink.table.api.internal that return Model Modifier and Type Method Description ModelTableEnvironmentImpl. fromModel(String modelPath)ModelTableEnvironmentImpl. fromModel(ModelDescriptor descriptor) -
Uses of Model in org.apache.flink.table.expressions
Methods in org.apache.flink.table.expressions with parameters of type Model Modifier and Type Method Description static ModelReferenceExpressionApiExpressionUtils. modelRef(String name, Model model)
-