Class ShowCreateUtil


  • @Internal
    public class ShowCreateUtil
    extends Object
    SHOW CREATE statement Util.
    • Method Summary

      All Methods Static Methods Concrete Methods 
      Modifier and Type Method Description
      static String buildShowCreateCatalogRow​(org.apache.flink.table.catalog.CatalogDescriptor catalogDescriptor)  
      static String buildShowCreateMaterializedTableRow​(org.apache.flink.table.catalog.ResolvedCatalogMaterializedTable table, org.apache.flink.table.catalog.ObjectIdentifier tableIdentifier, boolean isTemporary, boolean createOrAlter, ZoneId timeZoneId, org.apache.flink.table.expressions.SqlFactory sqlFactory)
      Show create materialized table statement only for materialized tables.
      static String buildShowCreateModelRow​(org.apache.flink.table.catalog.ResolvedCatalogModel model, org.apache.flink.table.catalog.ObjectIdentifier modelIdentifier, boolean isTemporary)  
      static String buildShowCreateTableRow​(org.apache.flink.table.catalog.ResolvedCatalogBaseTable<?> table, org.apache.flink.table.catalog.ObjectIdentifier tableIdentifier, boolean isTemporary, org.apache.flink.table.expressions.SqlFactory sqlFactory)  
      static String buildShowCreateViewRow​(org.apache.flink.table.catalog.ResolvedCatalogBaseTable<?> view, org.apache.flink.table.catalog.ObjectIdentifier viewIdentifier, boolean isTemporary)
      Show create view statement only for views.
    • Method Detail

      • buildShowCreateModelRow

        public static String buildShowCreateModelRow​(org.apache.flink.table.catalog.ResolvedCatalogModel model,
                                                     org.apache.flink.table.catalog.ObjectIdentifier modelIdentifier,
                                                     boolean isTemporary)
      • buildShowCreateTableRow

        public static String buildShowCreateTableRow​(org.apache.flink.table.catalog.ResolvedCatalogBaseTable<?> table,
                                                     org.apache.flink.table.catalog.ObjectIdentifier tableIdentifier,
                                                     boolean isTemporary,
                                                     org.apache.flink.table.expressions.SqlFactory sqlFactory)
      • buildShowCreateMaterializedTableRow

        public static String buildShowCreateMaterializedTableRow​(org.apache.flink.table.catalog.ResolvedCatalogMaterializedTable table,
                                                                 org.apache.flink.table.catalog.ObjectIdentifier tableIdentifier,
                                                                 boolean isTemporary,
                                                                 boolean createOrAlter,
                                                                 ZoneId timeZoneId,
                                                                 org.apache.flink.table.expressions.SqlFactory sqlFactory)
        Show create materialized table statement only for materialized tables.
      • buildShowCreateViewRow

        public static String buildShowCreateViewRow​(org.apache.flink.table.catalog.ResolvedCatalogBaseTable<?> view,
                                                    org.apache.flink.table.catalog.ObjectIdentifier viewIdentifier,
                                                    boolean isTemporary)
        Show create view statement only for views.
      • buildShowCreateCatalogRow

        public static String buildShowCreateCatalogRow​(org.apache.flink.table.catalog.CatalogDescriptor catalogDescriptor)