Class PartitionQueryOperation

  • All Implemented Interfaces:
    Operation, QueryOperation

    @Internal
    public class PartitionQueryOperation
    extends Object
    implements QueryOperation
    Describes a relational operation that was created from applying a partitioning.
    • Constructor Detail

      • PartitionQueryOperation

        public PartitionQueryOperation​(List<org.apache.flink.table.expressions.ResolvedExpression> partitionExpressions,
                                       QueryOperation child)
      • PartitionQueryOperation

        public PartitionQueryOperation​(List<org.apache.flink.table.expressions.ResolvedExpression> partitionExpressions,
                                       List<org.apache.flink.table.expressions.ResolvedExpression> orderExpressions,
                                       QueryOperation child)
    • Method Detail

      • getPartitionKeys

        public int[] getPartitionKeys()
      • getOrderExpressions

        public List<org.apache.flink.table.expressions.ResolvedExpression> getOrderExpressions()
      • getOrderKeys

        public int[] getOrderKeys()
      • getOrderDirections

        public org.apache.flink.table.functions.TableSemantics.SortDirection[] getOrderDirections()
      • asSummaryString

        public String asSummaryString()
        Description copied from interface: Operation
        Returns a string that summarizes this operation for printing to a console. An implementation might skip very specific properties.
        Specified by:
        asSummaryString in interface Operation
        Returns:
        summary string of this operation for debugging purposes
      • getResolvedSchema

        public org.apache.flink.table.catalog.ResolvedSchema getResolvedSchema()
        Description copied from interface: QueryOperation
        Resolved schema of this operation.
        Specified by:
        getResolvedSchema in interface QueryOperation