Class GenericInMemorySecretStore

  • All Implemented Interfaces:
    org.apache.flink.table.secret.ReadableSecretStore, org.apache.flink.table.secret.SecretStore, org.apache.flink.table.secret.WritableSecretStore

    @Internal
    public class GenericInMemorySecretStore
    extends Object
    implements org.apache.flink.table.secret.ReadableSecretStore, org.apache.flink.table.secret.WritableSecretStore
    A generic in-memory implementation of both ReadableSecretStore and WritableSecretStore.

    This implementation stores secrets in memory as immutable Map objects. It is suitable for testing and development purposes but should not be used in production environments as secrets are not encrypted.

    • Constructor Detail

      • GenericInMemorySecretStore

        public GenericInMemorySecretStore()
    • Method Detail

      • getSecret

        public Map<String,​String> getSecret​(String secretId)
                                           throws org.apache.flink.table.secret.exceptions.SecretNotFoundException
        Specified by:
        getSecret in interface org.apache.flink.table.secret.ReadableSecretStore
        Throws:
        org.apache.flink.table.secret.exceptions.SecretNotFoundException
      • storeSecret

        public String storeSecret​(Map<String,​String> secretData)
        Specified by:
        storeSecret in interface org.apache.flink.table.secret.WritableSecretStore
      • removeSecret

        public void removeSecret​(String secretId)
        Specified by:
        removeSecret in interface org.apache.flink.table.secret.WritableSecretStore
      • updateSecret

        public void updateSecret​(String secretId,
                                 Map<String,​String> newSecretData)
                          throws org.apache.flink.table.secret.exceptions.SecretNotFoundException
        Specified by:
        updateSecret in interface org.apache.flink.table.secret.WritableSecretStore
        Throws:
        org.apache.flink.table.secret.exceptions.SecretNotFoundException