Enum ExecutionConfigOptions.SinkUpsertMaterializeStrategy
- java.lang.Object
-
- java.lang.Enum<ExecutionConfigOptions.SinkUpsertMaterializeStrategy>
-
- org.apache.flink.table.api.config.ExecutionConfigOptions.SinkUpsertMaterializeStrategy
-
- All Implemented Interfaces:
Serializable,Comparable<ExecutionConfigOptions.SinkUpsertMaterializeStrategy>
- Enclosing class:
- ExecutionConfigOptions
@PublicEvolving public static enum ExecutionConfigOptions.SinkUpsertMaterializeStrategy extends Enum<ExecutionConfigOptions.SinkUpsertMaterializeStrategy>
SinkUpsertMaterializer strategy.
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ADAPTIVEAlternate between MAP and VALUE depending on the number of entries for the given key starting with VALUE and switching to MAP upon reaching threshold.high value (and back to VALUE, when reaching low).LEGACYSimple implementation based onValueState<List>(the original implementation).MAPOrderedMultiSetState-based implementation based on a combination of several MapState maintaining ordering and fast lookup properties.VALUESimilar to LEGACY, but compatible with MAP and therefore allows to switch to ADAPTIVE.
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static ExecutionConfigOptions.SinkUpsertMaterializeStrategyvalueOf(String name)Returns the enum constant of this type with the specified name.static ExecutionConfigOptions.SinkUpsertMaterializeStrategy[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
LEGACY
public static final ExecutionConfigOptions.SinkUpsertMaterializeStrategy LEGACY
Simple implementation based onValueState<List>(the original implementation).- optimal for cases with history under approx. 100 elements
- limited TTL support (per key granularity, i.e. no expiration for old history elements)
-
MAP
public static final ExecutionConfigOptions.SinkUpsertMaterializeStrategy MAP
OrderedMultiSetState-based implementation based on a combination of several MapState maintaining ordering and fast lookup properties.- faster and more memory-efficient on long histories
- slower on short histories
- currently, no TTL support (to be added in the future)
- requires more space
-
VALUE
public static final ExecutionConfigOptions.SinkUpsertMaterializeStrategy VALUE
Similar to LEGACY, but compatible with MAP and therefore allows to switch to ADAPTIVE.
-
ADAPTIVE
public static final ExecutionConfigOptions.SinkUpsertMaterializeStrategy ADAPTIVE
Alternate between MAP and VALUE depending on the number of entries for the given key starting with VALUE and switching to MAP upon reaching threshold.high value (and back to VALUE, when reaching low).
-
-
Method Detail
-
values
public static ExecutionConfigOptions.SinkUpsertMaterializeStrategy[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ExecutionConfigOptions.SinkUpsertMaterializeStrategy c : ExecutionConfigOptions.SinkUpsertMaterializeStrategy.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ExecutionConfigOptions.SinkUpsertMaterializeStrategy valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
-