Package org.apache.flink.table.secret
Class GenericInMemorySecretStore
- java.lang.Object
-
- org.apache.flink.table.secret.GenericInMemorySecretStore
-
- All Implemented Interfaces:
org.apache.flink.table.secret.ReadableSecretStore,org.apache.flink.table.secret.SecretStore,org.apache.flink.table.secret.WritableSecretStore
@Internal public class GenericInMemorySecretStore extends Object implements org.apache.flink.table.secret.ReadableSecretStore, org.apache.flink.table.secret.WritableSecretStore
A generic in-memory implementation of bothReadableSecretStoreandWritableSecretStore.This implementation stores secrets in memory as immutable Map objects. It is suitable for testing and development purposes but should not be used in production environments as secrets are not encrypted.
-
-
Constructor Summary
Constructors Constructor Description GenericInMemorySecretStore()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description Map<String,String>getSecret(String secretId)voidremoveSecret(String secretId)StringstoreSecret(Map<String,String> secretData)voidupdateSecret(String secretId, Map<String,String> newSecretData)
-
-
-
Method Detail
-
getSecret
public Map<String,String> getSecret(String secretId) throws org.apache.flink.table.secret.exceptions.SecretNotFoundException
- Specified by:
getSecretin interfaceorg.apache.flink.table.secret.ReadableSecretStore- Throws:
org.apache.flink.table.secret.exceptions.SecretNotFoundException
-
storeSecret
public String storeSecret(Map<String,String> secretData)
- Specified by:
storeSecretin interfaceorg.apache.flink.table.secret.WritableSecretStore
-
removeSecret
public void removeSecret(String secretId)
- Specified by:
removeSecretin interfaceorg.apache.flink.table.secret.WritableSecretStore
-
updateSecret
public void updateSecret(String secretId, Map<String,String> newSecretData) throws org.apache.flink.table.secret.exceptions.SecretNotFoundException
- Specified by:
updateSecretin interfaceorg.apache.flink.table.secret.WritableSecretStore- Throws:
org.apache.flink.table.secret.exceptions.SecretNotFoundException
-
-